CookieMiddleware

Struct CookieMiddleware 

pub struct CookieMiddleware {
    pub store: Arc<RwLock<CookieStore>>,
}
Middleware that keeps a shared cookie store across requests.

Fields

store: Arc<RwLock<CookieStore>>

Implementations

Source

impl CookieMiddleware

pub fn new() -> Self

Creates a new CookieMiddleware with a shared CookieStore.

pub fn with_store(store: CookieStore) -> Self

Creates a new CookieMiddleware with a pre-populated CookieStore.

pub async fn from_json<P: AsRef<Path>>(path: P) -> Result<Self, SpiderError>

Load cookies from a JSON file, replacing all cookies in the store. The JSON format is the one used by the cookie_store crate.

pub async fn from_netscape_file<P: AsRef<Path>>( path: P, ) -> Result<Self, SpiderError>

Load cookies from a Netscape cookie file. This will add to, not replace, the existing cookies in the store.

pub async fn from_rfc6265<P: AsRef<Path>>(path: P) -> Result<Self, SpiderError>

Load cookies from a file where each line is a Set-Cookie header value. The Domain attribute must be explicitly set in each cookie line.